@@ -49,13 +49,15 @@ install() {
 		if [ "$os" = "CentOS" ]; then
 			lsb_dist='centos'
 		else
-			vrsn=`cat /etc/debian_version`
+		  if [ -r /etc/debian_version ]; then
+        vrsn=`cat /etc/debian_version`
 
-		    if [ "$vrsn" = "jessie/sid" ]; then
-		    	lsb_dist='ubuntu14'
-		    else
-			    lsb_dist='debian'
-		    fi
+          if [ "$vrsn" = "jessie/sid" ]; then
+            lsb_dist='ubuntu14'
+          else
+            lsb_dist='debian'
+          fi
+      fi
 		fi
 
 	fi
@@ -74,15 +76,6 @@ install() {
 	if [ -z "$lsb_dist" ] && [ -r /etc/fedora-release ]; then
 		lsb_dist='fedora'
 	fi
-	if [ -z "$lsb_dist" ] && [ -r /etc/system-release ]; then
-		os=`cat /etc/system-release | awk -F ' ' {'print $1'}`
-
-		if [ "$os" = "CentOS" ]; then
-			lsb_dist='centos'
-		else
-			lsb_dist='amazon'
-		fi
-	fi
 	if [ -z "$lsb_dist" ] && [ -r /etc/centos-release ]; then
 		lsb_dist='centos'
 	fi
@@ -92,6 +85,15 @@ install() {
 	if [ -z "$lsb_dist" ] && [ -r /etc/SuSE-release ]; then
 		lsb_dist='suse'
 	fi
+	if [ -z "$lsb_dist" ] && [ -r /etc/system-release ]; then
+		os=`cat /etc/system-release | awk -F ' ' {'print $1'}`
+
+		if [ "$os" = "CentOS" ]; then
+			lsb_dist='centos'
+		else
+			lsb_dist='amazon'
+		fi
+	fi
 	if [ -z "$lsb_dist" ] && [ -r /etc/os-release ]; then
 		lsb_dist="$(. /etc/os-release && echo "$ID")"
 	fi
@@ -175,7 +177,7 @@ validate() {
     architecture=$(uname -m)
 	case $architecture in
 		# officially supported
-		amd64|x86_64)
+		amd64|x86_64|aarch64)
 			;;
 		# not supported
 		*)
